eqcorrscan.core.match\_filter.detection.read\_detections
========================================================

.. currentmodule:: eqcorrscan.core.match_filter.detection

.. autofunction:: read_detections